/**
 * @file bsp_lcd.c
 * @brief LCD initialize and basic operator.
 * @version 0.1
 * @date 2021-01-14
 * 
 * @copyright Copyright 2021 Espressif Systems (Shanghai) Co. Ltd.
 *
 *      Licensed under the Apache License, Version 2.0 (the "License");
 *      you may not use this file except in compliance with the License.
 *      You may obtain a copy of the License at
 *
 *               http://www.apache.org/licenses/LICENSE-2.0
 *
 *      Unless required by applicable law or agreed to in writing, software
 *      distributed under the License is distributed on an "AS IS" BASIS,
 *      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *      See the License for the specific language governing permissions and
 *      limitations under the License.
 */

#include "bsp_lcd.h"

static const char *TAG = "bsp_lcd";

#define TEST_IMG_SIZE (100 * 100 * sizeof(uint16_t))

esp_err_t bsp_lcd_init(void)
{
    ESP_LOGI(TAG, "bsp_lcd_init start");

    gpio_config_t bk_gpio_config = {
        .mode = GPIO_MODE_OUTPUT,
        .pin_bit_mask = 1ULL << GPIO_LCD_BL
    };
    ESP_ERROR_CHECK(gpio_config(&bk_gpio_config));

    esp_lcd_panel_handle_t panel_handle = NULL;
    esp_lcd_rgb_panel_config_t panel_config = {
        .data_width = 16, // RGB565 in parallel mode, thus 16bit in width
        .psram_trans_align = 64,
        .clk_src = LCD_CLK_SRC_DEFAULT,
        .disp_gpio_num = GPIO_NUM_NC,
        .pclk_gpio_num = GPIO_LCD_PCLK,
        .vsync_gpio_num = GPIO_LCD_VSYNC,
        .hsync_gpio_num = GPIO_LCD_HSYNC,
        .de_gpio_num = GPIO_LCD_DE,
        .data_gpio_nums = {
            GPIO_LCD_B0, GPIO_LCD_B1, GPIO_LCD_B2, GPIO_LCD_B3, GPIO_LCD_B4,         
            GPIO_LCD_G0, GPIO_LCD_G1, GPIO_LCD_G2, GPIO_LCD_G3, GPIO_LCD_G4, GPIO_LCD_G5,
            GPIO_LCD_R0, GPIO_LCD_R1, GPIO_LCD_R2, GPIO_LCD_R3, GPIO_LCD_R4,
        },
        .timings = {
            .h_res = LCD_WIDTH,
            .v_res = LCD_HEIGHT,
            // The following parameters should refer to LCD spec
       // #if  LCD_5r0_800x480
            .pclk_hz = 15 * 1000 * 1000,
            .hsync_back_porch = 42,
            .hsync_front_porch = 20,
            .hsync_pulse_width = 1,
            .vsync_back_porch = 12,
            .vsync_front_porch = 4,
            .vsync_pulse_width = 10,
     //   #endif
            .flags.pclk_active_neg = true,  // RGB data is clocked out on falling edge
        },
        .flags.fb_in_psram = true, // allocate frame buffer in PSRAM
    };
    ESP_ERROR_CHECK(esp_lcd_new_rgb_panel(&panel_config, &panel_handle));

    ESP_ERROR_CHECK(esp_lcd_panel_reset(panel_handle));
    ESP_ERROR_CHECK(esp_lcd_panel_init(panel_handle));
    // esp_lcd_panel_invert_color(panel_handle, true);
    // esp_lcd_panel_swap_xy(lcd_panel, true);
    // esp_lcd_panel_mirror(lcd_panel, true, false);

    ESP_LOGI(TAG, "Turn on LCD backlight");
    gpio_set_level(GPIO_LCD_BL, 1);
    ESP_LOGI(TAG, "LCD resolution: %dx%d", LCD_WIDTH, LCD_HEIGHT);

    lcd_clear_fast(panel_handle, COLOR_WHITE);
    // lcd_clear_fast(panel_handle, COLOR_RED);
    // lcd_clear_fast(panel_handle, COLOR_GREEN);
    // lcd_clear_fast(panel_handle, COLOR_BLUE);
    // lcd_clear_fast(panel_handle, COLOR_BLACK);
    // while (1)
    // {
    //     lcd_clear_fast(panel_handle, COLOR_WHITE);
    //     vTaskDelay(pdMS_TO_TICKS(2000));
    //     lcd_clear_fast(panel_handle, COLOR_RED);
    //     vTaskDelay(pdMS_TO_TICKS(2000));
    //     lcd_clear_fast(panel_handle, COLOR_GREEN);
    //     vTaskDelay(pdMS_TO_TICKS(2000));
    //     lcd_clear_fast(panel_handle, COLOR_BLUE);
    //     vTaskDelay(pdMS_TO_TICKS(2000));
    //     lcd_clear_fast(panel_handle, COLOR_BLACK);
    //     vTaskDelay(pdMS_TO_TICKS(2000));
    // }
    lcd_draw_picture_test(panel_handle);

    return ESP_OK;
}

esp_err_t lcd_clear(esp_lcd_panel_handle_t *panel, uint16_t color)
{
    uint16_t *buffer = heap_caps_malloc(LCD_WIDTH * sizeof(uint16_t), MALLOC_CAP_INTERNAL | MALLOC_CAP_8BIT);
    if (NULL == buffer) {
        ESP_LOGE(TAG, "Memory for bitmap is not enough");
        return ESP_FAIL;
    } else {
        for (uint16_t i = 0; i < LCD_WIDTH; i++) {
            buffer[i] = color;
        }
        for (int y = 0; y < LCD_HEIGHT; y++) {
            esp_lcd_panel_draw_bitmap(panel, 0, y, LCD_WIDTH, y+1, buffer);
        }
        heap_caps_free(buffer);
    }
    return ESP_OK;
}

esp_err_t lcd_clear_fast(esp_lcd_panel_handle_t *panel, uint16_t color)
{
    uint16_t fact = 68;
    // uint64_t s = esp_timer_get_time();
    uint16_t *buffer = heap_caps_malloc(LCD_WIDTH * fact * sizeof(uint16_t), MALLOC_CAP_SPIRAM);  //MALLOC_CAP_INTERNAL | MALLOC_CAP_8BIT
    if (NULL == buffer) {
        ESP_LOGE(TAG, "Memory for bitmap is not enough");
        return ESP_FAIL;
    } else {
        for (uint16_t i = 0; i < LCD_WIDTH * fact; i++) {
            buffer[i] = color;
        }
        for (int y = 0; y < LCD_HEIGHT; y += fact) {
            esp_lcd_panel_draw_bitmap(panel, 0, y, LCD_WIDTH, y + fact, buffer);
        }
        heap_caps_free(buffer);
    }
    // uint64_t t1 = (esp_timer_get_time() - s);
    // float time_per_frame = t1 / 1000;   
    // float fps = 1000000.f / (float)t1;
    // ESP_LOGI(TAG, "@resolution %ux%u  [time per frame=%.2fMS, fps=%.2f]", LCD_WIDTH, LCD_HEIGHT, time_per_frame, fps);
    return ESP_OK;
}

uint16_t rgb888_to_565(uint8_t r, uint8_t g, uint8_t b)
{
    return ((r & 0xF8) << 8) | ((g & 0xFC) << 3) | (b >> 3);
}

static const unsigned char gImage_img_120x39[];
void lcd_draw_picture_test(esp_lcd_panel_handle_t *panel)
{
    uint16_t *pixels = heap_caps_malloc((120 * 39) * sizeof(uint16_t), MALLOC_CAP_8BIT | MALLOC_CAP_INTERNAL);
    memcpy(pixels, gImage_img_120x39, (120 * 39) * sizeof(uint16_t));

    esp_lcd_panel_draw_bitmap(panel, 100, 100, 100+120, 100+39, (uint16_t *)pixels);
    heap_caps_free(pixels);
}

static const unsigned char gImage_img_120x39[9360] =  { /* 0X00,0X10,0X78,0X00,0X27,0X00,0X01,0X1B, */
    0X9D, 0XFF, 0X7D, 0XFF, 0X1D, 0XFF, 0XFD, 0XFE, 0X1E, 0XFF, 0X1E, 0XFF, 0X1D, 0XFF, 0X1C, 0XFF,
    0X1C, 0XFF, 0X1D, 0XFF, 0XFC, 0XFE, 0X1D, 0XFF, 0X1D, 0XFF, 0XFC, 0XFE, 0X1D, 0XFF, 0X1D, 0XFF,
    0X1C, 0XFF, 0X3C, 0XFF, 0X1D, 0XFF, 0X3D, 0XFF, 0X1D, 0XFF, 0X3D, 0XFF, 0X1D, 0XFF, 0X1D, 0XFF,
    0X1D, 0XFF, 0XFD, 0XFE, 0XFD, 0XFE, 0X1D, 0XFF, 0X1D, 0XFF, 0X3D, 0XFF, 0X3D, 0XFF, 0X1C, 0XFF,
    0X1C, 0XFF, 0X1C, 0XFF, 0X3D, 0XFF, 0X1D, 0XFF, 0X1D, 0XFF, 0X3E, 0XFF, 0X9F, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X9D, 0XFF, 0X08, 0X8A, 0X46, 0X91, 0X46, 0XA1, 0X27, 0X99, 0X46, 0X99, 0X46, 0X99, 0X66, 0X99,
    0X25, 0X99, 0X46, 0X99, 0X66, 0X99, 0X46, 0X99, 0X25, 0X99, 0X46, 0XA1, 0X66, 0XA1, 0X46, 0X99,
    0X25, 0X99, 0X46, 0X99, 0X66, 0X99, 0X46, 0X99, 0X46, 0X99, 0X66, 0X99, 0X46, 0X99, 0X46, 0X99,
    0X26, 0X99, 0X26, 0XA1, 0X26, 0XA1, 0X26, 0X99, 0X67, 0XA1, 0X66, 0X99, 0X46, 0X99, 0X66, 0XA1,
    0X45, 0X99, 0X46, 0XA1, 0X46, 0X99, 0X26, 0X99, 0X67, 0XA1, 0X05, 0X81, 0X97, 0XE5, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X5D, 0XFF, 0X86, 0X89, 0XC4, 0XA8, 0X83, 0XB8, 0XC5, 0XB8, 0XA4, 0XB0, 0XA3, 0XB0, 0XC3, 0XB0,
    0XA5, 0XB8, 0X84, 0XB0, 0XA3, 0XB8, 0XC3, 0XB8, 0X83, 0XB8, 0X84, 0XB8, 0X84, 0XB8, 0X84, 0XB8,
    0XA4, 0XB8, 0XA4, 0XB8, 0X63, 0XB0, 0X84, 0XB8, 0XA4, 0XB8, 0X83, 0XB0, 0XA3, 0XB8, 0XA3, 0XB8,
    0XA3, 0XB0, 0XA4, 0XB0, 0X84, 0XB8, 0XA4, 0XB8, 0XA3, 0XB0, 0X82, 0XB0, 0XA3, 0XB8, 0X83, 0XB8,
    0XA4, 0XB8, 0XA3, 0XB8, 0X83, 0XB0, 0XA4, 0XB8, 0XA5, 0XB8, 0X63, 0X90, 0X56, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0XC7, 0XA1, 0X83, 0XB0, 0X63, 0XC8, 0X84, 0XC8, 0X84, 0XC8, 0XC4, 0XC8, 0X83, 0XC0,
    0X84, 0XD0, 0X64, 0XC8, 0X83, 0XC8, 0X62, 0XC0, 0X84, 0XD0, 0X64, 0XC8, 0X84, 0XD0, 0X63, 0XC8,
    0X84, 0XC8, 0X63, 0XC8, 0X84, 0XC8, 0X64, 0XC0, 0X83, 0XB8, 0XC4, 0XB8, 0X82, 0XB8, 0XA3, 0XC0,
    0XC3, 0XC0, 0X83, 0XC0, 0X84, 0XC8, 0X84, 0XC8, 0X83, 0XC8, 0XA3, 0XC8, 0X83, 0XC8, 0X83, 0XC8,
    0X63, 0XC8, 0X83, 0XD0, 0XA3, 0XC8, 0XA3, 0XC8, 0X42, 0XC0, 0X83, 0XA8, 0X36, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X46, 0X99, 0XC4, 0XB0, 0XA4, 0XD0, 0X63, 0XC8, 0X63, 0XC8, 0X83, 0XC0, 0XA4, 0XC8,
    0X63, 0XC8, 0X84, 0XD0, 0X83, 0XC8, 0XA4, 0XD0, 0X64, 0XC8, 0X64, 0XC8, 0X84, 0XC8, 0X83, 0XC8,
    0X63, 0XC8, 0XA4, 0XC8, 0X84, 0XB8, 0X27, 0XB9, 0X87, 0XA9, 0X87, 0XA1, 0X25, 0XA1, 0XA3, 0X98,
    0X62, 0XA0, 0XA4, 0XB8, 0X63, 0XC0, 0X63, 0XC8, 0X63, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X83, 0XC8,
    0X83, 0XC8, 0X83, 0XC0, 0X62, 0XC0, 0XA3, 0XC8, 0X83, 0XC8, 0X63, 0XA0, 0X76, 0XF5, 0X9E, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0XA1, 0XA4, 0XB0, 0X42, 0XC0, 0X83, 0XD0, 0X83, 0XD0, 0X62, 0XC0, 0X83, 0XC8,
    0X83, 0XC8, 0XA4, 0XC8, 0X83, 0XC8, 0X83, 0XC0, 0XA5, 0XB8, 0X84, 0XB0, 0X63, 0XA8, 0X83, 0XA8,
    0XC4, 0XB8, 0X84, 0XB0, 0XA5, 0XA8, 0XBC, 0XFE, 0XFC, 0XFE, 0XFC, 0XFE, 0XFC, 0XFE, 0XF8, 0XFD,
    0X52, 0XF4, 0X09, 0XBA, 0X83, 0XA0, 0X83, 0XB0, 0X63, 0XC0, 0X63, 0XC8, 0XA4, 0XD0, 0X63, 0XC8,
    0X83, 0XC8, 0XA3, 0XC8, 0X82, 0XC0, 0XA3, 0XC8, 0X63, 0XC8, 0X42, 0XA0, 0X76, 0XF5, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0XA1, 0X83, 0XB8, 0X63, 0XC8, 0X83, 0XD0, 0X42, 0XC8, 0X84, 0XD0, 0X63, 0XC8,
    0X42, 0XB0, 0X83, 0XB8, 0XA4, 0XC0, 0XA4, 0XB0, 0X84, 0X90, 0X6F, 0XDB, 0X10, 0XE4, 0XCB, 0XBA,
    0X86, 0XA1, 0XA3, 0X98, 0X63, 0XA0, 0XA8, 0XC1, 0X52, 0XFC, 0X1D, 0XFF, 0X7E, 0XFF, 0X9E, 0XFF,
    0XBE, 0XFF, 0X7E, 0XFF, 0X18, 0XFE, 0X6B, 0XB2, 0XA4, 0XA0, 0X64, 0XB8, 0X64, 0XC0, 0X64, 0XC8,
    0X84, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X42, 0XC8, 0XA4, 0XB0, 0X56, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X87, 0XA1, 0XA3, 0XB8, 0X63, 0XD0, 0X63, 0XC8, 0X83, 0XC8, 0X84, 0XB8, 0XA4, 0XB0,
    0X15, 0XFD, 0X46, 0XC1, 0X83, 0XA8, 0X66, 0XB1, 0X39, 0XFE, 0X5E, 0XFF, 0X9D, 0XFF, 0X7D, 0XFF,
    0X5D, 0XFF, 0X39, 0XFE, 0X10, 0XEC, 0X46, 0X99, 0XC4, 0X88, 0X66, 0X81, 0X93, 0XD4, 0X9E, 0XFF,
    0XBE, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0X7E, 0XFF, 0XD4, 0XFC, 0XA4, 0X98, 0XA4, 0XB8, 0X84, 0XC8,
    0X84, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X63, 0XD0, 0X43, 0XA0, 0X56, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1E, 0XFF, 0X47, 0XA1, 0X84, 0XB8, 0X84, 0XD0, 0X43, 0XC8, 0XA4, 0XB8, 0XA4, 0X90, 0XB8, 0XFD,
    0XDC, 0XFE, 0X87, 0XB1, 0X05, 0X99, 0X1C, 0XFF, 0X7D, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0XBF, 0XFF,
    0XDF, 0XFF, 0XBF, 0XFF, 0XBE, 0XFF, 0X9E, 0XFF, 0XD7, 0XF5, 0X09, 0X92, 0XC4, 0X80, 0X87, 0X99,
    0XF7, 0XFD, 0X7D, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0X9B, 0XFE, 0XC4, 0X98, 0X83, 0XB8,
    0X83, 0XC0, 0X63, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X63, 0XC8, 0X42, 0XA0, 0X76, 0XF5, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1E, 0XFF, 0X67, 0XA1, 0X84, 0XB8, 0X83, 0XC8, 0XA4, 0XC8, 0X42, 0XA0, 0X52, 0XEC, 0X1C, 0XFF,
    0X09, 0XBA, 0XA3, 0X98, 0X66, 0XA1, 0X1C, 0XFF, 0X9D, 0XFF, 0XDE, 0XFF, 0X9F, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XDE, 0XFF, 0X9E, 0XFF, 0X7E, 0XFF, 0X15, 0XFD, 0X25, 0X91,
    0X03, 0X81, 0XCE, 0XCB, 0X9D, 0XFF, 0XBE, 0XFF, 0XDF, 0XFF, 0X9F, 0XFF, 0XBB, 0XFE, 0XE4, 0X98,
    0XA4, 0XB8, 0XA4, 0XC8, 0X63, 0XC8, 0X62, 0XC8, 0XA3, 0XD0, 0X62, 0XA0, 0X55, 0XED, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X87, 0XA1, 0XA4, 0XB0, 0XA4, 0XC8, 0XA4, 0XB8, 0X45, 0XB1, 0X3C, 0XFF, 0X51, 0XE4,
    0X62, 0XA0, 0X83, 0XB8, 0XE5, 0XB0, 0X9B, 0XFE, 0XDB, 0XFE, 0X5D, 0XFF, 0X5E, 0XFF, 0X7F, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBF, 0XFF, 0X9E, 0XFF, 0X5D, 0XFF,
    0XAA, 0XAA, 0XE3, 0X80, 0XAA, 0XBA, 0X5D, 0XFF, 0XDE, 0XFF, 0XDF, 0XFF, 0XBE, 0XFF, 0XF8, 0XFD,
    0X63, 0X98, 0XA4, 0XC0, 0X83, 0XC8, 0X43, 0XC8, 0X63, 0XD0, 0X83, 0XA8, 0X55, 0XF5, 0XDE, 0XFF,
    0XFE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3C, 0XFF, 0X86, 0XA1, 0XA4, 0XB8, 0X83, 0XB8, 0X82, 0X98, 0X96, 0XFD, 0XDB, 0XFE, 0XC3, 0X88,
    0XC4, 0XB0, 0XA4, 0XB8, 0X84, 0X98, 0XA4, 0X88, 0XE3, 0X78, 0X04, 0X71, 0XE8, 0X89, 0X2E, 0XAB,
    0X55, 0XE5, 0X9E, 0XFF, 0X9E, 0XFF, 0XBF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF,
    0X5D, 0XFF, 0XEF, 0XDB, 0XC3, 0X88, 0X49, 0XAA, 0X5D, 0XFF, 0X9E, 0XFF, 0XDF, 0XFF, 0X9E, 0XFF,
    0X8F, 0XE3, 0X63, 0XA8, 0X84, 0XC8, 0X63, 0XD0, 0X83, 0XD0, 0X62, 0XA0, 0X75, 0XF5, 0XDE, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3C, 0XFF, 0X66, 0X99, 0XA4, 0XC0, 0XA4, 0XB8, 0XC8, 0XA1, 0X1D, 0XFF, 0X8B, 0XDA, 0XA4, 0XA8,
    0X83, 0X98, 0XA8, 0XA9, 0XD0, 0XDB, 0XB3, 0XE4, 0X72, 0XD4, 0XCF, 0XBB, 0X6B, 0X9A, 0X26, 0X81,
    0XC4, 0X88, 0XE4, 0X90, 0X4D, 0XDB, 0XBB, 0XFE, 0X9E, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XBF, 0XFF, 0X7E, 0XFF, 0X93, 0XEC, 0XC4, 0X80, 0X4A, 0XAA, 0X5D, 0XFF, 0XBE, 0XFF, 0XBE, 0XFF,
    0X1D, 0XFF, 0X26, 0XA1, 0X84, 0XB8, 0X64, 0XC8, 0X84, 0XD0, 0X62, 0XA0, 0X76, 0XF5, 0XDF, 0XFF,
    0XFF, 0XFF, 0XDE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X66, 0XA1, 0XA4, 0XC0, 0X22, 0XA8, 0X73, 0XEC, 0X3D, 0XFF, 0XA4, 0X98, 0X83, 0XA0,
    0XD4, 0XFC, 0X3D, 0XFF, 0X7E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X5E, 0XFF, 0X1D, 0XFF,
    0X56, 0XFD, 0X6A, 0XC2, 0XA3, 0X88, 0X04, 0X81, 0X31, 0XCC, 0X9E, 0XFF, 0XBF, 0XFF, 0XDF, 0XFF,
    0XDF, 0XFF, 0XBF, 0XFF, 0X7F, 0XFF, 0X52, 0XDC, 0XC4, 0X88, 0X0C, 0XC3, 0X7E, 0XFF, 0XBE, 0XFF,
    0X9E, 0XFF, 0XD0, 0XDB, 0X63, 0XA8, 0X64, 0XC8, 0X63, 0XC8, 0X63, 0XA0, 0X76, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF,
    0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0XA7, 0XA1, 0X83, 0XB0, 0X63, 0XA8, 0X7B, 0XFE, 0X35, 0XED, 0XC3, 0X80, 0X55, 0XFD,
    0X7D, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XBE, 0XFF, 0XDE, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF,
    0X9F, 0XFF, 0X9E, 0XFF, 0X9A, 0XFE, 0X8A, 0X9A, 0XC4, 0X88, 0X09, 0XAA, 0XDB, 0XFE, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF, 0X9D, 0XFF, 0X6E, 0XCB, 0XA3, 0X78, 0X35, 0XED, 0X9E, 0XFF,
    0XBE, 0XFF, 0XBA, 0XFE, 0X83, 0XA0, 0X84, 0XC8, 0X63, 0XD0, 0X63, 0XA8, 0X56, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBB, 0XCE, 0XD4, 0X94,
    0XD4, 0X94, 0XFC, 0XD6, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X39, 0XC6, 0XF4, 0X94,
    0XD3, 0X94, 0XB7, 0XB5, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XD7, 0XB5, 0X52, 0X84,
    0X72, 0X8C, 0X93, 0X8C, 0X72, 0X8C, 0XB7, 0XAD, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBB, 0XCE,
    0X93, 0X8C, 0X72, 0X8C, 0X72, 0X8C, 0X93, 0X8C, 0XD8, 0XB5, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0X3D, 0XE7, 0X14, 0X9D, 0X92, 0X8C, 0X59, 0XC6, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBB, 0XD6, 0XD3, 0X94, 0X93, 0X8C, 0X15, 0X9D, 0X9E, 0XEF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9A, 0XCE, 0XD3, 0X94, 0XD3, 0X94, 0X55, 0XA5,
    0X7E, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDC, 0XDE, 0XDB, 0XD6, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X18, 0XBE, 0X31, 0X84, 0X92, 0X8C, 0X7A, 0XCE, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X86, 0X99, 0X83, 0XB0, 0X46, 0XC1, 0X1D, 0XFF, 0X0D, 0XAB, 0XCB, 0XAA, 0X7D, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XBE, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0X9E, 0XFF, 0XF4, 0XFC, 0XC3, 0X80, 0X65, 0X89, 0X79, 0XFE,
    0XBF, 0XFF, 0XBF, 0XFF, 0XFF, 0XFF, 0XDE, 0XFF, 0X5D, 0XFF, 0X09, 0X9A, 0XE4, 0X78, 0XDB, 0XFE,
    0XBE, 0XFF, 0X7D, 0XFF, 0XA7, 0XB9, 0X83, 0XC0, 0X63, 0XC8, 0X63, 0XA8, 0X56, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF0, 0X73, 0X87, 0X21, 0XEC, 0X52,
    0XCC, 0X52, 0X66, 0X29, 0X5D, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0X6E, 0X6B, 0X86, 0X29, 0XEC, 0X5A,
    0X0C, 0X5B, 0X08, 0X3A, 0XA7, 0X29, 0X9F, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0X29, 0X3A, 0XAB, 0X52,
    0X8F, 0X6B, 0X6E, 0X63, 0X6E, 0X63, 0XC8, 0X31, 0X4E, 0X63, 0XFF, 0XFF, 0XFF, 0XF7, 0XAF, 0X6B,
    0XA8, 0X31, 0XB0, 0X73, 0X6E, 0X63, 0X4E, 0X63, 0XC8, 0X31, 0XAF, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X55, 0XA5, 0X45, 0X21, 0XAB, 0X52, 0XEC, 0X5A, 0X66, 0X29, 0XF8, 0XBD,
    0XFF, 0XFF, 0XFF, 0XFF, 0X51, 0X84, 0X66, 0X29, 0XCB, 0X52, 0X0D, 0X5B, 0X8A, 0X4A, 0X45, 0X21,
    0X59, 0XC6, 0XFF, 0XFF, 0XFF, 0XFF, 0XF0, 0X7B, 0X45, 0X21, 0XCB, 0X52, 0X2D, 0X5B, 0X4A, 0X42,
    0X45, 0X21, 0X7A, 0XCE, 0XFF, 0XFF, 0XFF, 0XFF, 0X31, 0X84, 0X6E, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0X2D, 0X63, 0XA7, 0X29, 0XCF, 0X73, 0X2D, 0X5B, 0X66, 0X29, 0XF0, 0X7B, 0XFF, 0XFF,
    0X5C, 0XFF, 0X66, 0X91, 0XA4, 0XA8, 0XC9, 0XD1, 0XDD, 0XFE, 0X88, 0X81, 0X76, 0XE5, 0XBE, 0XFF,
    0XDF, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0X7E, 0XFF, 0X5D, 0XFF, 0X5D, 0XFF, 0X9E, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XBE, 0XFF, 0X38, 0XFE, 0XC3, 0X88, 0X04, 0X91,
    0XDC, 0XFE, 0X9F, 0XFF, 0XFE, 0XFF, 0XFE, 0XFF, 0XDF, 0XFF, 0XBB, 0XFE, 0XA3, 0X88, 0XAA, 0XC2,
    0X9D, 0XFF, 0X9D, 0XFF, 0XAB, 0XD2, 0X43, 0XB0, 0X64, 0XC8, 0X84, 0XA8, 0X36, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X93, 0X84, 0XC8, 0X31, 0X1C, 0XDF, 0XFF, 0XFF,
    0XFF, 0XFF, 0X5D, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0XF4, 0X9C, 0X08, 0X3A, 0X9E, 0XEF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X39, 0XBE, 0XBF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0X49, 0X42, 0X7A, 0XC6,
    0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XBF, 0XEF, 0X25, 0X19, 0XBB, 0XCE, 0XFF, 0XFF, 0X6F, 0X63,
    0X31, 0X7C, 0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XFF, 0X5E, 0XE7, 0X26, 0X21, 0XBC, 0XD6, 0XFF, 0XFF,
    0XFF, 0XF7, 0X7A, 0XC6, 0XE4, 0X10, 0X18, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0X9E, 0XF7, 0XBE, 0XF7,
    0XFF, 0XFF, 0X79, 0XCE, 0X45, 0X29, 0XBB, 0XD6, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBB, 0XD6,
    0X5D, 0XEF, 0XFF, 0XFF, 0XF9, 0XBD, 0X66, 0X29, 0XFB, 0XDE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X9B, 0XCE, 0X3D, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0X31, 0X84, 0X8E, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0X39, 0XBE, 0X87, 0X29, 0XBF, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0X1C, 0XDF, 0XD3, 0X94, 0XFF, 0XFF,
    0X5D, 0XFF, 0XA7, 0X99, 0X83, 0XA0, 0XCD, 0XF2, 0XBC, 0XFE, 0X05, 0X71, 0X7A, 0XFE, 0XBE, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XDB, 0XFE, 0X45, 0X61, 0X05, 0X71, 0XE8, 0X91, 0XAF, 0XBB, 0X79, 0XFE,
    0X5D, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF, 0X18, 0XFE, 0XC3, 0X88,
    0X87, 0X89, 0X7E, 0XFF, 0XDE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9E, 0XFF, 0X6E, 0XDB, 0XC3, 0X88,
    0X18, 0XFE, 0X5D, 0XFF, 0XD0, 0XF3, 0X83, 0XB0, 0X84, 0XC8, 0X63, 0XA8, 0X35, 0XED, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9F, 0XEF, 0XA8, 0X29, 0X7A, 0XC6, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X6E, 0X6B, 0XAF, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X29, 0X42, 0X7A, 0XC6,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X87, 0X29, 0X19, 0XBE, 0XFF, 0XFF, 0X8F, 0X6B,
    0X31, 0X7C, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X87, 0X29, 0X59, 0XC6, 0XFF, 0XFF,
    0XFF, 0XFF, 0X6A, 0X42, 0X15, 0X9D, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0X55, 0XA5, 0X29, 0X42, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XF4, 0X9C, 0X4A, 0X42, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0X52, 0X84, 0X8F, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0XB7, 0XAD, 0XAB, 0X4A, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0X91, 0X83, 0XA0, 0X0D, 0XF3, 0XDC, 0XFE, 0X04, 0X71, 0XBA, 0XFE, 0XDE, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XBD, 0XFF, 0X30, 0XB4, 0X0D, 0XAB, 0X87, 0X91, 0X04, 0X89, 0XC3, 0X88,
    0X6A, 0XBA, 0X9A, 0XFE, 0X9E, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0X9E, 0XFF, 0X76, 0XFD,
    0XA3, 0X88, 0X2D, 0XCB, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF, 0XDB, 0XFE, 0X04, 0X81,
    0XEC, 0XAA, 0X3D, 0XFF, 0X31, 0XFC, 0X62, 0XA0, 0XA3, 0XC0, 0X63, 0XA0, 0X76, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X97, 0XAD, 0XE9, 0X29, 0X7F, 0XDF, 0X7E, 0XE7, 0X7E, 0XE7,
    0X5E, 0XE7, 0X7E, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDC, 0XD6, 0X67, 0X21, 0X0D, 0X5B, 0XF9, 0XBD,
    0X3D, 0XE7, 0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XF7, 0XDF, 0XFF, 0XFF, 0XFF, 0X2A, 0X42, 0X36, 0X9D,
    0XDB, 0XD6, 0XBB, 0XD6, 0XBB, 0XCE, 0X6E, 0X63, 0XA7, 0X29, 0XFF, 0XF7, 0XFF, 0XF7, 0X8F, 0X6B,
    0X6E, 0X63, 0X1D, 0XDF, 0XBB, 0XD6, 0X9B, 0XCE, 0X4E, 0X63, 0X29, 0X42, 0XBF, 0XF7, 0XFF, 0XFF,
    0X9B, 0XCE, 0X25, 0X19, 0XFD, 0XD6, 0X9F, 0XE7, 0X5E, 0XE7, 0X7E, 0XE7, 0X3D, 0XDF, 0XFF, 0XF7,
    0XFF, 0XFF, 0XDF, 0XF7, 0XE8, 0X31, 0X49, 0X3A, 0X97, 0XAD, 0X3D, 0XDF, 0XDF, 0XEF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XF7, 0XBF, 0XEF, 0XE8, 0X31, 0X6A, 0X4A, 0X96, 0XAD, 0X1D, 0XDF, 0XBF, 0XF7,
    0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0X31, 0X7C, 0X8F, 0X6B, 0XDF, 0XF7, 0XFF, 0XFF,
    0X93, 0X8C, 0X8B, 0X42, 0XDC, 0XD6, 0X9B, 0XCE, 0XBB, 0XD6, 0X7A, 0XCE, 0X1C, 0XE7, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0X91, 0X82, 0XA0, 0X2D, 0XFB, 0XFB, 0XFE, 0X24, 0X71, 0XB2, 0XD4, 0X9D, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFE, 0XFF, 0XBE, 0XFF, 0X5E, 0XFF, 0X3E, 0XFF, 0X7A, 0XFE, 0X6D, 0XD3,
    0XC3, 0X88, 0XE4, 0X80, 0X35, 0XED, 0X9F, 0XFF, 0XBF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X7E, 0XFF,
    0X4E, 0XD3, 0XC3, 0X88, 0X18, 0XFE, 0XDE, 0XFF, 0XFE, 0XFF, 0XDE, 0XFF, 0X7E, 0XFF, 0X6F, 0XBB,
    0XE5, 0X80, 0X9B, 0XFE, 0XF0, 0XFB, 0X82, 0XB0, 0XA3, 0XC0, 0X63, 0XA0, 0X56, 0XF5, 0X9F, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X14, 0X9D, 0X05, 0X19, 0XA8, 0X29, 0X87, 0X21, 0X86, 0X21, 0X66, 0X21,
    0X46, 0X21, 0X46, 0X21, 0X3C, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0X5E, 0XDF, 0XF0, 0X7B, 0XE8, 0X39,
    0X46, 0X29, 0X67, 0X29, 0XB0, 0X6B, 0XBF, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0X6B, 0X42, 0X87, 0X29,
    0XC8, 0X31, 0XA7, 0X31, 0XA6, 0X31, 0X2D, 0X63, 0X7E, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF0, 0X73,
    0X66, 0X21, 0XA7, 0X31, 0X87, 0X29, 0X46, 0X21, 0X05, 0X19, 0XDB, 0XD6, 0XFF, 0XFF, 0X7B, 0XCE,
    0X25, 0X19, 0XC8, 0X29, 0X66, 0X21, 0X87, 0X21, 0X46, 0X21, 0X66, 0X21, 0X46, 0X21, 0X97, 0XAD,
    0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XF7, 0XD4, 0X94, 0X4A, 0X42, 0X46, 0X21, 0X67, 0X21, 0XEC, 0X5A,
    0XFB, 0XD6, 0XFF, 0XFF, 0XFF, 0XF7, 0XBF, 0XF7, 0X92, 0X8C, 0X29, 0X42, 0X46, 0X21, 0X67, 0X29,
    0X0D, 0X5B, 0X3C, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0X31, 0X7C, 0XAF, 0X6B, 0XFF, 0XFF, 0X97, 0XAD,
    0X66, 0X21, 0X87, 0X29, 0XC8, 0X31, 0XA7, 0X31, 0XC7, 0X31, 0X66, 0X29, 0XAF, 0X73, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0X99, 0X83, 0XA8, 0X8B, 0XEA, 0XFB, 0XFE, 0X86, 0X89, 0X65, 0X91, 0X3D, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0XBF, 0XFF, 0X9E, 0XFF,
    0X9A, 0XFE, 0XE7, 0X91, 0XA3, 0X80, 0XD4, 0XFC, 0X9E, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0X1C, 0XFF, 0X46, 0X81, 0X49, 0X9A, 0X7D, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF, 0XBF, 0XFF, 0X5B, 0XFE,
    0X84, 0X88, 0X88, 0XD1, 0XE4, 0XC0, 0X83, 0XC0, 0X63, 0XC8, 0X63, 0XA8, 0X56, 0XFD, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X76, 0XAD, 0XE9, 0X39, 0X9F, 0XE7, 0X7E, 0XE7, 0X7E, 0XE7,
    0X9E, 0XEF, 0X7D, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF,
    0XBE, 0XF7, 0X59, 0XC6, 0XAB, 0X4A, 0X2D, 0X5B, 0XFF, 0XFF, 0XFF, 0XFF, 0X49, 0X42, 0X39, 0XBE,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X8E, 0X6B,
    0X10, 0X7C, 0XFF, 0XFF, 0XFF, 0XFF, 0X9E, 0XEF, 0X6E, 0X6B, 0X0C, 0X5B, 0XFF, 0XFF, 0XFF, 0XFF,
    0XDC, 0XD6, 0X25, 0X19, 0XFC, 0XD6, 0X9E, 0XEF, 0X7E, 0XEF, 0X5D, 0XE7, 0X7E, 0XEF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBF, 0XF7, 0XDB, 0XD6, 0XAF, 0X73,
    0X08, 0X3A, 0X9E, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XDC, 0XCE,
    0X6E, 0X63, 0X2A, 0X42, 0XBF, 0XF7, 0XFF, 0XFF, 0X52, 0X84, 0X8F, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0X97, 0XAD, 0XAC, 0X4A, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X87, 0XA1, 0X63, 0XA8, 0X87, 0XC9, 0X1C, 0XFF, 0X49, 0X9A, 0XA3, 0X90, 0X4A, 0XC2,
    0X5E, 0XFF, 0XBF, 0XFF, 0XBE, 0XFF, 0X9E, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XBE, 0XFF, 0X5D, 0XFF, 0XC8, 0XA9, 0XC3, 0X88, 0X59, 0XFE, 0XBE, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0X9E, 0XFF, 0X31, 0XCC, 0XE4, 0X80, 0X18, 0XFE, 0XBE, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0X7F, 0XFF,
    0X68, 0XB1, 0X43, 0XB8, 0X84, 0XC8, 0X63, 0XC8, 0X63, 0XD0, 0X63, 0XA8, 0X35, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X7E, 0XEF, 0X67, 0X29, 0X7B, 0XC6, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X5E, 0XDF, 0X26, 0X19, 0X9E, 0XEF, 0XFF, 0XFF, 0X49, 0X42, 0X59, 0XC6,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X8E, 0X6B,
    0X11, 0X7C, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X7E, 0XEF, 0X46, 0X21, 0XFC, 0XDE, 0XFF, 0XFF,
    0XFF, 0XFF, 0X6A, 0X42, 0X14, 0X9D, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0XFF, 0XFF,
    0X87, 0X29, 0X39, 0XBE, 0XFF, 0XF7, 0XFF, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0X87, 0X29, 0X7A, 0XCE, 0XFF, 0XFF, 0X52, 0X84, 0X8F, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0X76, 0XA5, 0XCB, 0X4A, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X46, 0XA1, 0XA3, 0XB8, 0XE4, 0XB8, 0X3D, 0XFF, 0XAF, 0XCB, 0X84, 0XA8, 0X63, 0XB0,
    0X67, 0XB1, 0X55, 0XFD, 0XFC, 0XFE, 0X7D, 0XFF, 0X9E, 0XFF, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XDF, 0XFF, 0XBF, 0XFF, 0XFC, 0XFE, 0X04, 0X79, 0XC7, 0X89, 0X7D, 0XFF, 0XBF, 0XFF, 0XDF, 0XFF,
    0XDF, 0XFF, 0XFB, 0XFE, 0XC3, 0X88, 0X4D, 0XD3, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9E, 0XFF,
    0X4E, 0XDB, 0X63, 0XB0, 0XA4, 0XC8, 0X63, 0XC8, 0X83, 0XD0, 0X62, 0XA8, 0X56, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X73, 0X8C, 0XE9, 0X39, 0X1D, 0XDF, 0XFF, 0XF7,
    0XFF, 0XFF, 0X7A, 0XCE, 0X1C, 0XDF, 0XFF, 0XFF, 0XD8, 0XB5, 0X32, 0X7C, 0X7F, 0XEF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XD0, 0X73, 0XAC, 0X4A, 0XFF, 0XFF, 0XDF, 0XFF, 0X4A, 0X42, 0X19, 0XBE,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X8F, 0X73,
    0XF0, 0X7B, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XF7, 0X86, 0X29, 0X9B, 0XD6, 0XFF, 0XFF,
    0XFF, 0XFF, 0X18, 0XB6, 0X25, 0X19, 0X5A, 0XC6, 0XFF, 0XFF, 0XFF, 0XF7, 0X1D, 0XDF, 0XBB, 0XCE,
    0XFF, 0XF7, 0XDC, 0XD6, 0X8F, 0X6B, 0X3D, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF7, 0X76, 0XA5,
    0X86, 0X29, 0X7E, 0XEF, 0XBB, 0XCE, 0XD0, 0X73, 0X3D, 0XE7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X15, 0X9D, 0XA7, 0X29, 0XBE, 0XF7, 0XFF, 0XFF, 0X52, 0X84, 0X8F, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0X96, 0XAD, 0X8B, 0X4A, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFD, 0XFE, 0X87, 0XA9, 0X63, 0XB8, 0X63, 0XA8, 0XF8, 0XFD, 0XB8, 0XFD, 0X63, 0XA8, 0X84, 0XC0,
    0X83, 0XB8, 0X83, 0XA0, 0X25, 0X99, 0X86, 0X91, 0X6A, 0XAA, 0X55, 0XED, 0X9D, 0XFF, 0XDF, 0XFF,
    0XDF, 0XFF, 0XBF, 0XFF, 0X9E, 0XFF, 0XB2, 0XDC, 0XE3, 0X80, 0X14, 0XFD, 0X9F, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0X9E, 0XFF, 0XE7, 0XB1, 0X45, 0XA1, 0X9E, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBF, 0XFF,
    0X14, 0XFD, 0X62, 0XA0, 0X83, 0XC0, 0XA4, 0XD0, 0X62, 0XC8, 0X62, 0XA0, 0X76, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XF1, 0X7B, 0X46, 0X21, 0XCC, 0X52,
    0XAB, 0X52, 0X25, 0X21, 0X39, 0XC6, 0XFF, 0XFF, 0XDC, 0XD6, 0X8B, 0X4A, 0X66, 0X29, 0X6B, 0X4A,
    0X0D, 0X5B, 0XA8, 0X31, 0XE8, 0X31, 0X1D, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0X09, 0X3A, 0X39, 0XC6,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X29, 0X42,
    0X72, 0X8C, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X86, 0X29, 0X6E, 0X6B, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0X35, 0X9D, 0X46, 0X21, 0X4A, 0X42, 0X0D, 0X5B, 0X25, 0X21, 0XF4, 0X94,
    0XFF, 0XFF, 0X9F, 0XEF, 0X2D, 0X5B, 0X66, 0X21, 0X4A, 0X42, 0X4E, 0X5B, 0X29, 0X3A, 0X86, 0X21,
    0X18, 0XBE, 0XFF, 0XFF, 0X9E, 0XEF, 0X0C, 0X5B, 0X45, 0X21, 0X29, 0X42, 0X4E, 0X63, 0XE8, 0X31,
    0X87, 0X29, 0X18, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0X31, 0X84, 0X6E, 0X6B, 0XFF, 0XFF, 0XFF, 0XFF,
    0X76, 0XAD, 0X6A, 0X42, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X66, 0XA1, 0X84, 0XB8, 0X43, 0XB0, 0X6E, 0XD3, 0X1D, 0XFF, 0X05, 0XB1, 0X63, 0XB8,
    0XA3, 0XC0, 0XA3, 0XB8, 0XA3, 0XA0, 0X83, 0X98, 0X63, 0XA0, 0XA3, 0X98, 0X4D, 0XC3, 0X7D, 0XFF,
    0XDF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0X9D, 0XFF, 0XC3, 0X90, 0X29, 0XBA, 0X9E, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XBE, 0XFF, 0XEF, 0XEB, 0XA3, 0X88, 0X1C, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XBF, 0XFF,
    0X79, 0XFE, 0X62, 0X98, 0XE4, 0XC0, 0X63, 0XC8, 0X83, 0XC8, 0X83, 0XA0, 0X75, 0XED, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFC, 0XD6, 0X35, 0X9D,
    0X15, 0XA5, 0XFB, 0XDE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFC, 0XDE, 0X35, 0XA5,
    0XF4, 0X9C, 0X18, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XBB, 0XD6, 0X9F, 0XF7,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XF8, 0XBD,
    0XBE, 0XF7, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X7A, 0XCE, 0XF8, 0XBD, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X5D, 0XE7, 0X76, 0XAD, 0XF4, 0X9C, 0X9A, 0XD6, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X3D, 0XE7, 0X96, 0XAD, 0XB3, 0X94, 0XB7, 0XB5, 0X7E, 0XEF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X1C, 0XE7, 0X55, 0XAD, 0XD3, 0X94, 0XB7, 0XB5,
    0X9E, 0XEF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X3D, 0XE7, 0X1C, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X7E, 0XEF, 0X9A, 0XCE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0XA7, 0XA1, 0XA4, 0XB8, 0X83, 0XB8, 0X05, 0X99, 0XFC, 0XFE, 0X11, 0XFC, 0XA3, 0XA0,
    0XA3, 0XB0, 0XE4, 0XB0, 0X52, 0XFC, 0X36, 0XFD, 0X6B, 0XDA, 0XA3, 0XA0, 0XA3, 0X90, 0XD3, 0XF4,
    0X9E, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X7D, 0XFF, 0XEB, 0XD2, 0XC3, 0X90, 0X5E, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0X9E, 0XFF, 0X55, 0XFD, 0XC3, 0X88, 0XD7, 0XF5, 0XDF, 0XFF, 0XFF, 0XFF, 0X9E, 0XFF,
    0X39, 0XFE, 0XA3, 0XA0, 0X83, 0XB8, 0XA4, 0XD0, 0X63, 0XC8, 0X62, 0X98, 0X96, 0XF5, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0XA7, 0X99, 0XA3, 0XB0, 0X82, 0XC0, 0X62, 0XA8, 0X11, 0XFC, 0XFD, 0XFE, 0X66, 0X89,
    0XE4, 0X88, 0X7A, 0XFE, 0X7E, 0XFF, 0X5E, 0XFF, 0X5E, 0XFF, 0X2E, 0XC3, 0X63, 0X98, 0XE8, 0XB9,
    0XBD, 0XFF, 0XFF, 0XFF, 0XFE, 0XFF, 0XBE, 0XFF, 0X50, 0XF4, 0XC3, 0X88, 0X9A, 0XFE, 0XDF, 0XFF,
    0XFF, 0XFF, 0XBF, 0XFF, 0XD7, 0XFD, 0XE3, 0X88, 0X13, 0XD5, 0XBE, 0XFF, 0XDF, 0XFF, 0X7E, 0XFF,
    0X09, 0XC2, 0X83, 0XB8, 0X63, 0XC8, 0X63, 0XC8, 0X83, 0XD0, 0X83, 0XA0, 0X55, 0XED, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3E, 0XFF, 0X87, 0X99, 0XA2, 0XA8, 0XC3, 0XC8, 0X83, 0XC0, 0X62, 0XA0, 0X1D, 0XFF, 0XF8, 0XFD,
    0X08, 0X8A, 0X7D, 0XFF, 0XBE, 0XFF, 0XDF, 0XFF, 0XBF, 0XFF, 0X19, 0XFE, 0X83, 0XA8, 0XE5, 0XA8,
    0X7D, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XBE, 0XFF, 0XB3, 0XFC, 0XC3, 0X80, 0X59, 0XF6, 0XDF, 0XFF,
    0XFF, 0XFF, 0XBF, 0XFF, 0X7A, 0XFE, 0X82, 0X80, 0X91, 0XE4, 0X5D, 0XFF, 0X5D, 0XFF, 0X11, 0XE4,
    0X43, 0XA0, 0X84, 0XC8, 0X84, 0XC8, 0X84, 0XD0, 0X63, 0XC8, 0X63, 0XA8, 0X56, 0XF5, 0XDF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XDF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X67, 0X99, 0XC4, 0XB0, 0X62, 0XC0, 0XA3, 0XD0, 0X62, 0XB8, 0X29, 0XBA, 0X3D, 0XFF,
    0XD3, 0XCC, 0XBE, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9E, 0XFF, 0X55, 0XFD, 0X63, 0XA8, 0X26, 0XB1,
    0X5E, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0X9F, 0XFF, 0XB4, 0XFC, 0XA3, 0X80, 0X59, 0XF6, 0XFF, 0XFF,
    0XFF, 0XFF, 0XBE, 0XFF, 0X3A, 0XFE, 0XA4, 0X90, 0X66, 0XB1, 0X87, 0XC1, 0X67, 0XC1, 0X63, 0XA8,
    0XA4, 0XC0, 0X84, 0XC8, 0X83, 0XC0, 0X84, 0XC8, 0X63, 0XC8, 0X63, 0XA8, 0X56, 0XFD, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X67, 0XA1, 0XA4, 0XB8, 0X83, 0XC8, 0X62, 0XC8, 0XA3, 0XC8, 0X83, 0XA0, 0XB0, 0XE3,
    0X5E, 0XFF, 0XFB, 0XFE, 0XBE, 0XFF, 0XDE, 0XFF, 0XDB, 0XFE, 0XA7, 0XA9, 0X63, 0XA0, 0X6A, 0XCA,
    0X9F, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0X9F, 0XFF, 0X8F, 0XE3, 0XE4, 0X90, 0XDB, 0XFE, 0XFF, 0XFF,
    0XFF, 0XFF, 0XBE, 0XFF, 0XD8, 0XFD, 0XA4, 0X98, 0XA4, 0XB0, 0X83, 0XB0, 0X84, 0XB0, 0XC9, 0XD9,
    0X42, 0XB8, 0X83, 0XC8, 0X83, 0XC8, 0X63, 0XC0, 0X84, 0XC8, 0X83, 0XA8, 0X35, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X67, 0XA1, 0X84, 0XB8, 0X63, 0XC8, 0XA3, 0XC8, 0X82, 0XC0, 0X83, 0XC0, 0X63, 0XA0,
    0XF1, 0XEB, 0X3E, 0XFF, 0X34, 0XDD, 0X08, 0X8A, 0XC4, 0X98, 0X83, 0XA8, 0XE4, 0XA8, 0X9B, 0XFE,
    0XBF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0X7D, 0XFF, 0X08, 0XBA, 0X25, 0X99, 0X9E, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0X9E, 0XFF, 0XD4, 0XFC, 0X83, 0X98, 0XA3, 0XA0, 0XE4, 0X98, 0X19, 0XFE, 0XFD, 0XFE,
    0XE5, 0XB8, 0X83, 0XC8, 0X63, 0XC8, 0X84, 0XD0, 0X63, 0XC8, 0X63, 0XA0, 0X56, 0XF5, 0XBF, 0XFF,
    0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X1D, 0XFF, 0X87, 0XA1, 0X64, 0XB8, 0X84, 0XC8, 0XA3, 0XC0, 0XA3, 0XC0, 0X83, 0XC8, 0X84, 0XC0,
    0X84, 0XA0, 0X4E, 0XE3, 0XFC, 0XFE, 0XF7, 0XFD, 0X46, 0XB1, 0X83, 0XA0, 0XE4, 0X98, 0X72, 0XEC,
    0X7E, 0XFF, 0X9E, 0XFF, 0X9D, 0XFF, 0X99, 0XFE, 0X82, 0X98, 0X49, 0XD2, 0X3D, 0XFF, 0X9E, 0XFF,
    0XBF, 0XFF, 0XDC, 0XFE, 0X4A, 0XB2, 0XA3, 0X90, 0XAB, 0XCA, 0XFC, 0XFE, 0X1D, 0XFF, 0XE9, 0XA9,
    0XA3, 0XB0, 0X63, 0XC8, 0X63, 0XC8, 0X84, 0XD0, 0X63, 0XC8, 0X63, 0XA0, 0X56, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X86, 0XA1, 0XA4, 0XB8, 0X63, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X63, 0XC8, 0X84, 0XC8,
    0X84, 0XC0, 0X63, 0XB0, 0XA8, 0XB9, 0XBB, 0XFE, 0X3C, 0XFF, 0XF3, 0XF4, 0XA7, 0X99, 0XC4, 0X80,
    0X0A, 0XAA, 0XF1, 0XE3, 0X76, 0XFD, 0X8A, 0XD2, 0X62, 0XA8, 0X62, 0XB0, 0XE4, 0XA8, 0XAC, 0XD2,
    0XC8, 0X99, 0X05, 0X71, 0X8A, 0XA2, 0X39, 0XFE, 0X1C, 0XFF, 0X55, 0XFD, 0XE5, 0XA8, 0X83, 0XB0,
    0X83, 0XC0, 0X83, 0XC8, 0X83, 0XC0, 0X83, 0XC0, 0X63, 0XC8, 0X63, 0XA8, 0X55, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X86, 0X99, 0XA4, 0XB8, 0X83, 0XC8, 0X63, 0XC0, 0X83, 0XC8, 0XA4, 0XD0, 0X63, 0XC8,
    0X84, 0XD0, 0X63, 0XC0, 0X84, 0XB0, 0X83, 0X90, 0X6E, 0XCB, 0X3D, 0XFF, 0XFC, 0XFE, 0X19, 0XFE,
    0X8F, 0XEB, 0X09, 0XBA, 0X05, 0XA1, 0X83, 0X98, 0XE4, 0XA8, 0XE5, 0XB0, 0X26, 0XC1, 0X4A, 0XDA,
    0X52, 0XFC, 0XBC, 0XFE, 0X1D, 0XFF, 0X59, 0XFE, 0X49, 0XBA, 0XA3, 0X98, 0XA4, 0XC0, 0X43, 0XC0,
    0X63, 0XC8, 0X83, 0XC8, 0X83, 0XC0, 0XA3, 0XC8, 0X84, 0XD0, 0X63, 0XA8, 0X55, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X87, 0XA1, 0X84, 0XB0, 0X84, 0XC8, 0XA4, 0XC8, 0X83, 0XC0, 0X63, 0XC8, 0X43, 0XD0,
    0X63, 0XC8, 0XA4, 0XC8, 0X63, 0XC0, 0XC5, 0XC0, 0X84, 0XB0, 0X63, 0XA0, 0X8B, 0XDA, 0X14, 0XFD,
    0XFC, 0XFE, 0XFD, 0XFE, 0XFD, 0XFE, 0X1D, 0XFF, 0X1D, 0XFF, 0XFD, 0XFE, 0X1D, 0XFF, 0XFC, 0XFE,
    0X9A, 0XFE, 0X92, 0XFC, 0XC7, 0XC9, 0X41, 0XA0, 0XA3, 0XB8, 0XA3, 0XC0, 0X63, 0XC0, 0XA4, 0XC8,
    0X84, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0X63, 0XC8, 0X42, 0XA0, 0X76, 0XFD, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFC, 0XFE, 0X87, 0XA1, 0XA5, 0XB8, 0X84, 0XC8, 0XC4, 0XC0, 0XC4, 0XC0, 0X84, 0XC8, 0X84, 0XD0,
    0X63, 0XC8, 0XA4, 0XC8, 0X83, 0XC0, 0X84, 0XC8, 0X64, 0XC8, 0X84, 0XC0, 0X83, 0XA8, 0XC3, 0XA0,
    0XC3, 0X90, 0XC8, 0XA1, 0X8B, 0XBA, 0XED, 0XC2, 0XED, 0XBA, 0XED, 0XBA, 0X6A, 0XAA, 0X86, 0X99,
    0XA2, 0X90, 0X82, 0X98, 0X82, 0XB0, 0XC4, 0XC8, 0X83, 0XC8, 0X63, 0XC0, 0XA4, 0XC8, 0X83, 0XC0,
    0XA4, 0XC0, 0X84, 0XC8, 0X83, 0XC8, 0X83, 0XC8, 0XA4, 0XC8, 0X63, 0XA0, 0X56, 0XFD, 0X9E, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X3D, 0XFF, 0X46, 0X91, 0X43, 0XA8, 0X44, 0XC0, 0X63, 0XB0, 0X83, 0XB0, 0X83, 0XB8, 0X63, 0XB8,
    0X63, 0XB8, 0X62, 0XB8, 0X83, 0XB8, 0X63, 0XB8, 0X83, 0XB8, 0X63, 0XB8, 0X83, 0XB8, 0X62, 0XA8,
    0XA3, 0XA8, 0X83, 0XA0, 0X62, 0XA0, 0X83, 0XA0, 0X83, 0XA0, 0XA4, 0XA0, 0X63, 0XA0, 0X83, 0XA0,
    0XC4, 0XB0, 0X83, 0XA8, 0X83, 0XB0, 0X83, 0XB8, 0X42, 0XB0, 0X83, 0XB8, 0X84, 0XB8, 0X63, 0XB0,
    0X43, 0XB8, 0X63, 0XB8, 0X63, 0XB8, 0X63, 0XB8, 0X63, 0XB0, 0X83, 0X98, 0X56, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0X7E, 0XFF, 0X4E, 0XBB, 0X8C, 0XCA, 0XAC, 0XDA, 0XAC, 0XCA, 0XCC, 0XCA, 0XAB, 0XCA, 0XAB, 0XD2,
    0XAB, 0XD2, 0XAB, 0XCA, 0XEC, 0XDA, 0X8B, 0XD2, 0XAB, 0XD2, 0XAC, 0XD2, 0XCB, 0XDA, 0XAB, 0XD2,
    0XAB, 0XD2, 0XCB, 0XD2, 0X8A, 0XD2, 0XAB, 0XD2, 0X8B, 0XD2, 0X8B, 0XD2, 0X8B, 0XD2, 0XAC, 0XD2,
    0X8B, 0XCA, 0XAC, 0XD2, 0XCC, 0XD2, 0XAC, 0XD2, 0XAC, 0XD2, 0XAC, 0XD2, 0XCC, 0XD2, 0XCC, 0XD2,
    0XAC, 0XD2, 0XAC, 0XD2, 0XAC, 0XD2, 0XAC, 0XD2, 0XAB, 0XCA, 0XCC, 0XBA, 0XF8, 0XF5, 0XBF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XBF, 0XFF, 0X7E, 0XFF, 0X9F, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0XBE, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF,
    0X9E, 0XFF, 0X9E, 0XFF, 0X7E, 0XFF, 0X9F, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF,
    0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF,
    0X9E, 0XFF, 0X9F, 0XFF, 0X7F, 0XFF, 0X9F, 0XFF, 0X7E, 0XFF, 0X9E, 0XFF, 0X7E, 0XFF, 0X9E, 0XFF,
    0X9F, 0XFF, 0X7E, 0XFF, 0X7E, 0XFF, 0X9E, 0XFF, 0X9E, 0XFF, 0X9D, 0XFF, 0XDF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
    0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF, 0XFF,
};



